@@ -46,7 +46,7 @@
 //  #define SOCKET_BUG
 //  #define FDCAT_BUG
 //  #define SEND_RECV_BUG
-
+//  #define MIME_BASE64_BUG
 
 
   /* ---- bufer ---- */
@@ -83,8 +83,9 @@
   char * delim_get(char *, char *, char, int *, int);
   char * swap_rn(char *, char);
   char * safe_ujtoj(char *);
-  char * safe_base64(char *, int);
+  char * safe_base64(char *);
   char * safe_base64inheader(char *, char *);
+  char * mime_ujtoj(char *);
 
   /* --- socket --- */
   int socket_reads(int, char * , int, int);
@@ -99,7 +100,8 @@
   int unlinkdir(char *);
 
   /* --- sp --- */
-  int base64(char *, int, char *, int);
+  int base64(char *, int, char *);
+  char * base64_kai(char *);
   int ujtoj(unsigned char *, unsigned char *);
 
   /* --- time --- */
