@@ -171,21 +171,41 @@ if($num > 0){
          $BNAME_OLD = enco_rtrim(db_fetch_Result($result, $s, bname));
          }
 
-      $result = db_query($conn, "update userblock set
-        youname='$YOUNAME',
-        bname='$BNAME', 
-        cname='$CNAME',
-        mailsend='$MAILSEND',
-        stat='$STAT',
-        plustime=$PLUSTIME,
-        starttime='$STARTTIME',
-        stopsettime='$STOPSETTIME',
-        mailto='$MAILTO',
-        mailcc='$MAILCC',
-        free1='$FREE1',
-        free2='NOT',
-        free3='NOT'
-        where bname='$BNAME'");
+      if("ON" == $KANSHI){
+         $result = db_query($conn, "update userblock set
+           youname='$BNAME',
+           bname='$BNAME', 
+           cname='$CNAME',
+           mailsend='$MAILSEND',
+           stat='$STAT',
+           plustime=$PLUSTIME,
+           starttime='$STARTTIME',
+           stopsettime='$STOPSETTIME',
+           mailto='$MAILTO',
+           mailcc='$MAILCC',
+           free1='$FREE1',
+           free2='NOT',
+           free3='NOT'
+           where bname='$BNAME'");
+          }
+
+      else{
+         $result = db_query($conn, "update userblock set
+           youname='$YOUNAME',
+           bname='$BNAME', 
+           cname='$CNAME',
+           mailsend='$MAILSEND',
+           stat='$STAT',
+           plustime=$PLUSTIME,
+           starttime='$STARTTIME',
+           stopsettime='$STOPSETTIME',
+           mailto='$MAILTO',
+           mailcc='$MAILCC',
+           free1='$FREE1',
+           free2='NOT',
+           free3='NOT'
+           where bname='$BNAME'");
+          }
 
       print("OK ƻܤ֤Ƥޤ\n");
       $result =db_query($conn,
