@@ -47,19 +47,19 @@ print("ƻ륯饤 $CNAME εưեԽǤޤ\n");
 
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
    }
 
-$result = pg_query($conn, "select * from config where c_name='$CNAME'");
+$result = db_query($conn, "select * from config where c_name='$CNAME'");
 if(!$result){
    print("bud query\n");
    exit;
    }
 
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("no data\n");
    exit;
@@ -72,21 +72,21 @@ echo "<TABLE border=3  WIDTH=50% height=10% BGCOLOR=#e6e8fa>";
 $s = 0;
 while($s < $num){
 
-   $C_NAME = enco_rtrim(pg_fetch_Result($result, $s, c_name));
-   $C_INFO = enco_rtrim(pg_fetch_Result($result, $s, c_info));
-   $SOCK_IPADDR = enco_rtrim(pg_fetch_Result($result, $s, sock_ipaddr));
-   $SOCK2_IPADDR = enco_rtrim(pg_fetch_Result($result, $s, sock2_ipaddr));
-   $SOCK_PORT = enco_rtrim(pg_fetch_Result($result, $s, sock_port));
-   $SOCK2_PORT = enco_rtrim(pg_fetch_Result($result, $s, sock2_port));
-   $BAT_FILE = enco_rtrim(pg_fetch_Result($result, $s, bat_file));
-   $BAT2_FILE = enco_rtrim(pg_fetch_Result($result, $s, bat2_file));
-   $COMMAND_PATH = enco_rtrim(pg_fetch_Result($result, $s, command_path));
-   $BAT_INT = enco_rtrim(pg_fetch_Result($result, $s, bat_int));
-   $BAT2_INT = enco_rtrim(pg_fetch_Result($result, $s, bat2_int));
-   $LIFE_INT = enco_rtrim(pg_fetch_Result($result, $s, life_int));
-   $LIFE_LOS = enco_rtrim(pg_fetch_Result($result, $s, life_los));
-   $MAIL_CC = enco_rtrim(pg_fetch_Result($result, $s, mail_cc));
-   $UPDATE_COM = enco_rtrim(pg_fetch_Result($result, $s, update_com));
+   $C_NAME = enco_rtrim(db_fetch_Result($result, $s, c_name));
+   $C_INFO = enco_rtrim(db_fetch_Result($result, $s, c_info));
+   $SOCK_IPADDR = enco_rtrim(db_fetch_Result($result, $s, sock_ipaddr));
+   $SOCK2_IPADDR = enco_rtrim(db_fetch_Result($result, $s, sock2_ipaddr));
+   $SOCK_PORT = enco_rtrim(db_fetch_Result($result, $s, sock_port));
+   $SOCK2_PORT = enco_rtrim(db_fetch_Result($result, $s, sock2_port));
+   $BAT_FILE = enco_rtrim(db_fetch_Result($result, $s, bat_file));
+   $BAT2_FILE = enco_rtrim(db_fetch_Result($result, $s, bat2_file));
+   $COMMAND_PATH = enco_rtrim(db_fetch_Result($result, $s, command_path));
+   $BAT_INT = enco_rtrim(db_fetch_Result($result, $s, bat_int));
+   $BAT2_INT = enco_rtrim(db_fetch_Result($result, $s, bat2_int));
+   $LIFE_INT = enco_rtrim(db_fetch_Result($result, $s, life_int));
+   $LIFE_LOS = enco_rtrim(db_fetch_Result($result, $s, life_los));
+   $MAIL_CC = enco_rtrim(db_fetch_Result($result, $s, mail_cc));
+   $UPDATE_COM = enco_rtrim(db_fetch_Result($result, $s, update_com));
    
    $s++;
    }
@@ -253,8 +253,8 @@ echo"</table>";
 
 echo "</form>";
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 print("</font>");
 
