@@ -153,20 +153,21 @@ if(0 == strcmp($select_data, "select * from connection where " . "cname LIKE '%'
    echo "<TABLE border=0 cellspacing=0 cellpadding=3 WIDTH=80% BGCOLOR=#e6e8fa>";
    }
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
    }
 
-$result = enco_pg_query($conn, $select_data);
+// $result = enco_pg_query($conn, $select_data);
+$result = db_query($conn, enco($select_data));
 if(!$result){
    print("bud query\n");
    exit;
    }
-pg_Close($conn);
+db_Close($conn);
 
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("no data\n");
    exit;
@@ -205,20 +206,20 @@ echo "<td $kcal2><font size=1>*</font></td>";
 echo "</tr>"; 
 
 while($s < $num){
-   $UCT = enco_rtrim(pg_fetch_Result($result, $s, uct));
-   $YE = enco_rtrim(pg_fetch_Result($result, $s, ye));
-   $MO = enco_rtrim(pg_fetch_Result($result, $s, mo));
-   $DA = enco_rtrim(pg_fetch_Result($result, $s, da));
-   $HA = enco_rtrim(pg_fetch_Result($result, $s, ha));
-   $MI = enco_rtrim(pg_fetch_Result($result, $s, mi));
-   $SE = enco_rtrim(pg_fetch_Result($result, $s, se));
-   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
-   $SERVER = enco_rtrim(pg_fetch_Result($result, $s, server));
-   $MODE = enco_rtrim(pg_fetch_Result($result, $s, mode));
-   $STAT = enco_rtrim(pg_fetch_Result($result, $s, stat));
-   $VER = enco_rtrim(pg_fetch_Result($result, $s, ver));
-   $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
+   $UCT = enco_rtrim(db_fetch_Result($result, $s, uct));
+   $YE = enco_rtrim(db_fetch_Result($result, $s, ye));
+   $MO = enco_rtrim(db_fetch_Result($result, $s, mo));
+   $DA = enco_rtrim(db_fetch_Result($result, $s, da));
+   $HA = enco_rtrim(db_fetch_Result($result, $s, ha));
+   $MI = enco_rtrim(db_fetch_Result($result, $s, mi));
+   $SE = enco_rtrim(db_fetch_Result($result, $s, se));
+   $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+   $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
+   $SERVER = enco_rtrim(db_fetch_Result($result, $s, server));
+   $MODE = enco_rtrim(db_fetch_Result($result, $s, mode));
+   $STAT = enco_rtrim(db_fetch_Result($result, $s, stat));
+   $VER = enco_rtrim(db_fetch_Result($result, $s, ver));
+   $UNO = enco_rtrim(db_fetch_Result($result, $s, uno));
 
    $blo = block_count($CNAME);
    $clo = monitor_count_client($CNAME);
@@ -282,8 +283,8 @@ while($s < $num){
    }
 
 
-pg_free_result($result);
-// pg_Close($conn);
+db_free_result($result);
+// db_Close($conn);
 
 
 
