@@ -42,7 +42,12 @@ return 0;
 
 int opt_version(void)
 {
+#ifdef NET_SNMP_IN
+printf("------- %s for net-snmp -------\n", CL_VAR);
+#else
 printf("------- %s -------\n", CL_VAR);
+#endif
+
 printf("     -c /*/** config file path\n");
 printf("\n");
 exit(1);
