@@ -148,6 +148,7 @@ for(co = 0; sa.swap_data[pd->sb.fdno][co][0] != 0x00; co++){
                #endif 
                scan_comand(pd);
                }
+            #ifdef NET_SNMP_IN
             else if(0 == self_memcmp(pd->sb.ch_tool, "SNMP")){
                #ifdef MONITOR_BUG
                printf("MONITOR: %s: %s: %s: %s:\n",
@@ -155,6 +156,7 @@ for(co = 0; sa.swap_data[pd->sb.fdno][co][0] != 0x00; co++){
                #endif 
                scan_snmp(&pd->sb);
                }
+            #endif
             else if(0 == self_memcmp(pd->sb.ch_tool, "SET")){
                #ifdef MONITOR_BUG
                printf("MONITOR: %s: %s: %s: %s:\n",
@@ -164,10 +166,16 @@ for(co = 0; sa.swap_data[pd->sb.fdno][co][0] != 0x00; co++){
                }
             else{
                #ifdef MONITOR_BUG
-               printf("MONITOR: 存在しない属性が設定されています %s: %s: %s: %s:\n",
+               printf("scan_block(): 存在しない監視属性が設定されています %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
-               #endif
-               goto protoloopout;
+               #endif 
+
+               pd->sb.ch_info = safe_sprintf(pd->sb.ch_info, BUF_MAX,"%s : %s : %s : %s : %s\n",
+                 MONITOR_ERR_1, pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
+               pd->sb.check_stat = 1;
+               pd->sb.ch_plai = safe_memcpy(pd->sb.ch_plai, "6", BUF_MAX); 
+
+//               goto protoloopout;
                }
 
 
