@@ -1,5 +1,8 @@
 
 
+#ifdef NET_SNMP_IN
+
+
 #include<stdio.h>
 #include<netinet/in.h>
 #include<string.h>
@@ -475,13 +478,13 @@ else {
 // テストとッめ|チuッVドの凃
 if(0 == self_memcmp(pd->ch_plai, "4")){
    #ifdef SNMP_DEBUG
-   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
+   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%s check_stat=%d\n", pd->ch_plai, pd->check_stat);
    #endif
    ret = -1;
    }
 else if(0 == self_memcmp(pd->ch_plai, "11")){
    #ifdef SNMP_DEBUG
-   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
+   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%s check_stat=%d\n", pd->ch_plai, pd->check_stat);
    #endif
    if(ret == -1){
       pd->ch_plai = safe_memcpy(pd->ch_plai, "1", BUF_MAX);
@@ -490,7 +493,7 @@ else if(0 == self_memcmp(pd->ch_plai, "11")){
    }
 else if(0 == self_memcmp(pd->ch_plai, "12")){
    #ifdef SNMP_DEBUG
-   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
+   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%s check_stat=%d\n", pd->ch_plai, pd->check_stat);
    #endif
    if(ret == -1){
       pd->ch_plai = safe_memcpy(pd->ch_plai, "2", BUF_MAX);
@@ -499,7 +502,7 @@ else if(0 == self_memcmp(pd->ch_plai, "12")){
    }
 else if(0 == self_memcmp(pd->ch_plai, "13")){
    #ifdef SNMP_DEBUG
-   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
+   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%s check_stat=%d\n", pd->ch_plai, pd->check_stat);
    #endif
    if(ret == -1){
       pd->ch_plai = safe_memcpy(pd->ch_plai, "3", BUF_MAX);
@@ -544,4 +547,9 @@ return(ret);
 }
 
 
+#endif
+
+
+
+
 
