@@ -1,14 +1,22 @@
-
 #include<stdio.h>
+#include<string.h>
 #include<netdb.h>
 #include<unistd.h>
+#include<sys/socket.h>
+#include<netinet/in_systm.h>
+#include<netinet/in.h>
+#include<netinet/ip.h>
 #include<netinet/ip_icmp.h>
+#include<sys/stat.h>
+#include<arpa/inet.h>
 
 #include"sitar_scan.h"
+#include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
 
+
 /* 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
 int scan_udp_connect(int, char *, char *, int);
 */
@@ -48,7 +56,7 @@ ip_addr2 = inet_ntoa(send_addr.sin_addr);
 printf("UDP: scan_udp_connect(2): UDP host<%s> ip<%s>\n",ip_addr2, ip_addr);
 #endif
 
-// UDP ソケットを作る
+// UDP ゃXゃAットをXる
 if((send_sk = socket(AF_INET, SOCK_DGRAM, 0)) < 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
     "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_1);
@@ -59,7 +67,7 @@ if((send_sk = socket(AF_INET, SOCK_DGRAM, 0)) < 0){
    return backdata;
    }
 
-// RAWソケットを作る
+// RAWゃXゃAットをXる
 if((recv_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
     "IP=%s Port=%d ICMP %s", ip_addr, port, SOCK_1);
@@ -70,7 +78,7 @@ if((recv_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    return backdata;
    }
 
-// UDPソケットの送信
+// UDPゃXゃAットぃ送\B
 send_addr.sin_port = htons(port);
 sendto(send_sk, NULL, 0, 0, (struct sockaddr *)(long int)&send_addr, sizeof(send_addr));
 
@@ -81,20 +89,20 @@ while(1){
    FD_ZERO(&select_fd);
    FD_SET(recv_sk, &select_fd);
 
-   // selectでタイムアウト
+   // selectぃ@ゃ\めAムめuゃ
    if((select_stat = select(recv_sk + 1, &select_fd, NULL, NULL, &tv)) > 0){
       struct ip *ip;
       int hlen;
       int ports;
-      // RAWソケットの受け取り
+      // RAWゃXゃAットぃ受け取り
       if(recvfrom(recv_sk, buff, 1024, 0, NULL, NULL) != 56){
          #ifdef UDP_BUG
          printf("UDP: scan_udp_connect(5): ");
-         printf("(%d %d)サイズ違いのパケットを受け取りました、始めから\n", recv_sk, select_stat);
+         printf("(%d %d)ゃIめAゃR違いぃパケットを受け取りました、@めから\n", recv_sk, select_stat);
          #endif
          continue;
          }
-      // 受信パケットの評価
+      // 受\Bパケットぃ評ZB
       ip = (struct ip *)(long int)buff;
       hlen = ip->ip_hl << 2;
       icmp = (struct icmp*)(buff + hlen);
@@ -105,7 +113,7 @@ while(1){
          || (ports != port)){
          #ifdef UDP_BUG
          printf("UDP: scan_udp_connect(6): ");
-         printf("(%d %d)ポート不達でないICMPパケットを受け取ってます、始めから\n", recv_sk, select_stat);
+         printf("(%d %d)ポートN達ぃ@ぃFいICMPパケットを受け取ぁvぃぃZす、@めから\n", recv_sk, select_stat);
          #endif
          continue;
          }
@@ -114,7 +122,7 @@ while(1){
            "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_7);
          #ifdef UDP_BUG
          printf("UDP: scan_udp_connect(7): ");
-         printf("(%d %d)ポート不達ICMPパケットを受け取ってます、エラー\n", recv_sk, select_stat);
+         printf("(%d %d)ポートN達ICMPパケットを受け取ぁvぃぃZす、エッDッV\n", recv_sk, select_stat);
          #endif
          close(send_sk);
          close(recv_sk);
@@ -131,7 +139,7 @@ while(1){
          ip_addr, port, (se==NULL)?"unknown":se->s_name, SOCK_3);
       #ifdef UDP_BUG
       printf("UDP: scan_udp_connect(8): RECV %s", backdata);
-      printf("(%d %d) タイムアウトしました\n", recv_sk, select_stat);
+      printf("(%d %d) ゃ\めAムめuゃトしぃZした\n", recv_sk, select_stat);
       #endif
       close(send_sk);
       close(recv_sk);
@@ -150,7 +158,7 @@ backdata=safe_sprintf(backdata,BUF_MAX,
  "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_5);
 #ifdef UDP_BUG
 printf("UDP: scan_udp_connect(10): END %s", backdata);
-printf("(%d %d)戻りパケットをうけとれませんでした。エラー\n", recv_sk, select_stat);
+printf("(%d %d)戃TりパゃAットをうけとれませんぃ@した。エッDッV\n", recv_sk, select_stat);
 #endif
 
 
