@@ -31,7 +31,7 @@
 /* print conf */
   #define PRINT_CONF
 
-
+//  拡張デバッグオプション
 //  #define LIFE_DEBUG
 //  #define MYPEXEC_DEBUG 
 //  #define MUTEX_BUG
@@ -63,7 +63,7 @@
   typedef struct global_data global_data_t;
 
    struct global_data {
-
+     int cron_onoff;                   // CRON 機能を使う1使わない0
      struct thread_data{
         char ** mutex_name;
         char ** middle_name;
@@ -78,8 +78,8 @@
         int ls;
         struct sockaddr_in my_addr;
         unsigned int my_addrlen;
-        char * ip_addr;           /* active */
-        char * ip2_addr;          /* active */
+        char * ip_addr;                // active 
+        char * ip2_addr;               /* active */
         int port;
         int port2;
         }ip;
