@@ -2,6 +2,9 @@
 // $Id: snmp_test.c,v 1.3 2007/10/02 10:22:12 sendan Exp $
 // masashi shimakura
 
+
+#ifdef NET_SNMP_IN
+
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-includes.h>
 #include <string.h>
@@ -314,7 +317,7 @@ return data;
 
 
 
- 
+#endif 
 
 
 
