@@ -35,8 +35,11 @@ int count2 = 0;
 char chA;
 char data[2][BUF_SLEN];
 char * swap;
-char * recdata;
+char * recdata; 
+
 char * alllock_filename = (char *)calloc(BUF_DEFLEN, sizeof(char));
+char * swapsubject = (char *)calloc(BUF_DEFLEN, sizeof(char));
+char * swapdata = (char *)calloc(BUF_DEFLEN, sizeof(char));
 
 ret = 0;
 for(;;){
@@ -128,25 +131,32 @@ for(;;){
    fprintf(stdout,"DEBUG: clockfile_check(): %s\n", recdata);
    #endif
 
-   swap_mem(recdata, '\n', (char)0x01, (int)strlen(recdata));
 
    if(2 < (int)strlen(recdata)){
 
+   // subject を作ります
+      swapsubject = make_subject(swapsubject, CLIENT_BODY_4, "administrator");
+
+   // 本文を作ります
+      swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", CLIENT_BODY_3, recdata, CL_VAR);
+      swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+
       mail_grsend(gd.md.ch_MailServ,
               gd.md.ch_MailFrom,
               gd.md.ch_MailRcptTo,
               " ",
-              "zither administrator",
-              CLIENT_BODY_3, 
-              recdata,
-              CLIENT_BODY_4,
-              CL_VAR);
+              swapdata,
+              swapsubject,
+              gd.on_bcc,
+              "1");
       }
 
    free(recdata);
    } /* for(;;) */
 
 free(alllock_filename);
+free(swapsubject);
+free(swapdata);
 
 return(ret);
 }      
