@@ -22,8 +22,6 @@ extern global_data_t gd;
 
 
 
-
-
 // zither main()カラ最初ニ分岐スルスレッド
 int connect_open(int fdno)
 {
@@ -32,6 +30,9 @@ int ret = 0;
 int neg = 0;
 private_data_t *pd;
 
+char * swapsubject = (char *)calloc(BUF_DEFLEN, sizeof(char));
+char * swapdata = (char *)calloc(BUF_DEFLEN, sizeof(char));
+
 if((pd = (private_data_t *)malloc(sizeof(private_data_t)))==NULL){exit(1);}
 private_malloc_set(pd);
 pd->rec.fdno = fdno;
@@ -79,6 +80,7 @@ else{
    close(gd.ms.sk[pd->rec.fdno]);
    private_malloc_free(pd);
    free(pd);
+   free(swapsubject);
    return 0;
    }
 
@@ -136,7 +138,7 @@ if(neg >= 1){
       "NON");
 
    pthread_mutex_lock(&pg_mutex);
-   psqlexec_datain(swap);
+   psqlexec_datain(pd, swap);
    pthread_mutex_unlock(&pg_mutex);
    #ifdef POSTGRES_DEBUG
    printf("POSTGRES_DEBUG: connect_open(): >>%s\n", swap);
@@ -202,31 +204,44 @@ if(neg >= 1){
 
 
 
-
    if(gd.md.in_mailonoff == 1){
       if(0 == self_memcmp(pd->rec.def_user, "administrator")){
+
+         // subject を作ります
+         swapsubject = make_subject(swapsubject, ADMIN_BODY_2, pd->rec.def_user);
+
+         // 本文をつくります
+         swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.info, ADMIN_BODY_1, CL_VAR);
+         swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+
          mail_grsend(pd->mail.server,
               pd->mail.from,
               pd->mail.rcptto,
               pd->mail.cc,
-              pd->rec.def_user,
-              pd->rec.info,
-              ADMIN_BODY_1,
-              ADMIN_BODY_2,
-              CL_VAR);
+              swapdata,
+              swapsubject,
+              "NOT",
+              "1");
          }
       else{
+
+         // subject を作ります
+         swapsubject = make_subject(swapsubject, CLIENT_BODY_2, pd->rec.def_user);
+
+         // 本文をつくります
+         swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.info, CLIENT_BODY_1, CL_VAR);
+         swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+
          mail_grsend(pd->mail.server,
               pd->mail.from,
               pd->mail.rcptto,
               pd->mail.cc,
-              pd->rec.def_user,
-              pd->rec.info,
-              CLIENT_BODY_1,
-              CLIENT_BODY_2,
-              CL_VAR);
+              swapdata,
+              swapsubject,
+              "NOT",
+              "1");
          }
-      }
+     }
 
 
    #ifdef LOG_OUT
@@ -259,6 +274,8 @@ fprintf(stderr,"connect_open(): thread Management number %d plivate memory openi
 
 private_malloc_free(pd);
 free(pd);
+free(swapsubject);
+free(swapdata);
 
 return 0;
 }
