@@ -16,25 +16,35 @@
 #define MAIL_BODY_1 "Υ֥åϥ᡼ˡưַ⡼1ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬3Ϣ³ƹԤɬפޤ\n\n\n"
 #define MAIL_BODY_2 "Υ֥åϥ᡼ˡưַ⡼2ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬Ԥɬפޤ\n\n\n"
 
-#define ADMIN_BODY_1 "Administratorޥzitherδѹǽޤ\r\n̵꤬Τ륤餫⤷ޤ \r\nǰΤᡢôԤ˳ǧƤߤƤ  "
+#define ADMIN_BODY_1 "Administratorޥzitherδѹǽޤ\n̵꤬Τ륤餫⤷ޤ \r\nǰΤᡢôԤ˳ǧƤߤƤ  "
 
 #define ADMIN_BODY_2 "ưѹԤޤ "
 
-#define CLIENT_BODY_1  "ƻ륯饤ȤȤ³ޤ\r\nΰդ̵Хȥ֥βǽޤ \r\n δƻ륯饤ȤǼ¹ԤƤƻϡƼ¹ԤƤޤ "
+#define CLIENT_BODY_1  "ƻ륯饤ȤȤ³ޤ\nΰդ̵Хȥ֥βǽޤ \n δƻ륯饤ȤǼ¹ԤƤƻϡƼ¹ԤƤޤ "
 #define CLIENT_BODY_2 "饤Ȥ³ڤޤ "
 
-#define CLIENT_BODY_3 "zitherФ˲³sitarƻ륯饤Ȥ³򼺤äޤ֤Ƥޤ\r\n⤷³ɬפ̵LOCKե뤳ȤǤΥ᡼ʤʤޤ "
-#define CLIENT_BODY_4 "ƻ륯饤Ȥ Ǥ  "
+#define CLIENT_BODY_3 "zitherФ˲³sitarƻ륯饤Ȥ³򼺤äޤ֤Ƥޤ\n⤷³ɬפ̵LOCKե뤳ȤǤΥ᡼ʤʤޤ "
+#define CLIENT_BODY_4 "ƻ륯饤Ȥ Ǥ"
 
 #define CLIENT_BODY_5 "饤Ȥ³ޤ "
 
-#define CLIENT_BODY_6 "ѥåȥ¬ "
+#define CLIENT_BODY_6 "sitarȤ³˥ѥåȥ¬ޤ "
 
 #define CLIENT_BODY_7 "QUIT ޥɤᡢδƻ륯饤ȤȤ³Ǥޤ "
 
 #define CLIENT_BODY_8 "ƻ륯饤Ȥ "
 
-#define CLIENT_BODY_9 "顼¬ޤ "
+// #define CLIENT_BODY_9 "顼¬ޤ "
+#define CLIENT_BODY_9 "ƻǥ顼¬ޤ "
+
+#define CLIENT_BODY_10 "顼¬ޤΤǡʲδƻƤǧƤ  "
+
+#define CLIENT_BODY_11 "ǡ١˽񤭹ޤƤʤǽޤ\nǧƤ\nɬפʤƵưƤ  "
+
+
+#define CLIENT_BODY_12 "ǡ١³ǤƤޤ  "
+
+#define CLIENT_BODY_13 "ƻܤԽϰʲURLԤȤǤޤ "
 
 #define CLIENT_HEAD_1 "ƻ륯饤ȤȤ̳ǧ "
 #define CLIENT_HEAD_2 "ä٤¬ޤ \nƻ륯饤Ȥ˲٤٤ʤ \nͥåȥ˰۾郎̵ǧƤ "
@@ -63,9 +73,9 @@
 // 顼᡼
 
 
-#define MAIL_PR_1 "Ķ⤤׳ǧ"   // 1
-#define MAIL_PR_2 "⤤ "              // 2
-#define MAIL_PR_3 "㤤 "              // 3 ᡼ʤ
+#define MAIL_PR_1 " "                // 1
+#define MAIL_PR_2 " "                // 2
+#define MAIL_PR_3 " "                // 3 ᡼ʤ
 
 
 #define MAIL_DATA_1 "ƻܤιԿ¿ᡢƻϳ줬ǽޤ׳ǧ"
@@ -73,7 +83,7 @@
 #define MAIL_SNMP_11 "-- SNMPƻΥ顼 --"
 #define MAIL_SNMP_12 "      : "
 #define MAIL_SNMP_13 "        : "
-#define MAIL_SNMP_14 "        : "
+#define MAIL_SNMP_14 "ۥ̾    : " 
 #define MAIL_SNMP_15 "SNMP OID    : "
 #define MAIL_SNMP_16 "ƻ    : "
 #define MAIL_SNMP_17 "ƻ  : "
@@ -81,8 +91,8 @@
 
 #define MAIL_DHW_11 "-- DHWΥޥɤǥ顼Τޤ --"
 #define MAIL_DHW_12 "      : "
-#define MAIL_DHW_13 "̿ˡ    : "
-#define MAIL_DHW_14 "        : "
+#define MAIL_DHW_13 "ץȥ  : "
+#define MAIL_DHW_14 "ۥ̾    : " 
 #define MAIL_DHW_15 "DHWޥ : "
 #define MAIL_DHW_16 "Ԥ    : "
 #define MAIL_DHW_17 "ƻ    : "
@@ -91,8 +101,8 @@
 
 #define MAIL_DHW_21 "-- DHWޥɤνϤ֤Ƥޤ --"
 #define MAIL_DHW_22 "      : "
-#define MAIL_DHW_23 "̿ˡ    : "
-#define MAIL_DHW_24 "        : "
+#define MAIL_DHW_23 "ץȥ  : "
+#define MAIL_DHW_24 "ۥ̾    : " 
 #define MAIL_DHW_25 "DHWޥ : "
 #define MAIL_DHW_26 "Ԥ    : "
 #define MAIL_DHW_27 "ƻ    : "
@@ -101,7 +111,7 @@
 
 #define MAIL_URL_11 "-- ʲURLޤ --"
 #define MAIL_URL_12 "      : "
-#define MAIL_URL_13 "̿ˡ    : "
+#define MAIL_URL_13 "ץȥ  : "
 #define MAIL_URL_14 "URL         : "
 #define MAIL_URL_15 "ƻݡ  : "
 #define MAIL_URL_16 "Ԥ    : "
@@ -111,7 +121,7 @@
 
 #define MAIL_URL_21 "-- ʲURLǽǤ --"
 #define MAIL_URL_22 "      : "
-#define MAIL_URL_23 "̿ˡ    : "
+#define MAIL_URL_23 "ץȥ  : "
 #define MAIL_URL_24 "URL         : "
 #define MAIL_URL_25 "ƻݡ  : "
 #define MAIL_URL_26 "Ԥ    : "
@@ -121,7 +131,7 @@
 
 #define MAIL_SMTP_11 "-- ʲSMTPФѽޤ --"
 #define MAIL_SMTP_12 "      : "
-#define MAIL_SMTP_13 "̿ˡ    : "
+#define MAIL_SMTP_13 "ץȥ  : "
 #define MAIL_SMTP_14 "SMTP  : "
 #define MAIL_SMTP_15 "ƻݡ  : "
 #define MAIL_SMTP_16 "Ԥ    : "
@@ -131,7 +141,7 @@
 
 #define MAIL_SMTP_21 "-- ʲSMTPФѲǽǤ --"
 #define MAIL_SMTP_22 "      : "
-#define MAIL_SMTP_23 "̿ˡ    : "
+#define MAIL_SMTP_23 "ץȥ  : "
 #define MAIL_SMTP_24 "SMTP  : "
 #define MAIL_SMTP_25 "ƻݡ  : "
 #define MAIL_SMTP_26 "Ԥ    : "
@@ -141,7 +151,7 @@
 
 #define MAIL_NTP_11 "-- ʲNTPФȤλֺޤ --"
 #define MAIL_NTP_12 "      : "
-#define MAIL_NTP_13 "̿ˡ    : "
+#define MAIL_NTP_13 "ץȥ  : "
 #define MAIL_NTP_14 "NTP   : "
 #define MAIL_NTP_15 "ƻݡ  : "
 #define MAIL_NTP_16 "Ԥ    : "
@@ -151,7 +161,7 @@
 
 #define MAIL_NTP_21 "-- ʲNTPФȤλֺϤޤ --"
 #define MAIL_NTP_22 "      : "
-#define MAIL_NTP_23 "̿ˡ    : "
+#define MAIL_NTP_23 "ץȥ  : "
 #define MAIL_NTP_24 "NTP   : "
 #define MAIL_NTP_25 "ƻݡ  : "
 #define MAIL_NTP_26 "Ԥ    : "
@@ -161,8 +171,8 @@
 
 #define MAIL_PORT_11 "-- ʲΥݡȤĤƤޤ --"
 #define MAIL_PORT_12 "      : "
-#define MAIL_PORT_13 "̿ˡ    : "
-#define MAIL_PORT_14 "        : "
+#define MAIL_PORT_13 "ץȥ  : "
+#define MAIL_PORT_14 "ۥ̾    : " 
 #define MAIL_PORT_15 "ƻݡ  : "
 #define MAIL_PORT_16 "Ԥ    : "
 #define MAIL_PORT_17 "ƻ    : "
@@ -171,8 +181,8 @@
 
 #define MAIL_PORT_21 "-- ʲΥݡȤƤޤ --"
 #define MAIL_PORT_22 "      : "
-#define MAIL_PORT_23 "̿ˡ    : "
-#define MAIL_PORT_24 "        : "
+#define MAIL_PORT_23 "ץȥ  : "
+#define MAIL_PORT_24 "ۥ̾    : " 
 #define MAIL_PORT_25 "ƻݡ  : "
 #define MAIL_PORT_26 "Ԥ    : "
 #define MAIL_PORT_27 "ƻ    : "
@@ -196,7 +206,7 @@
 #define MAIL_COMMAND_27 "Error    : "
 
 #define MONITOR_ID      "ƻֹ    : " 
-#define MONITOR_SER     "ƻԽ    : " 
+#define MONITOR_SER     "ƻǧ    : " 
 
 
 #define MAIL_CTL_1     "ٹ "
@@ -205,7 +215,6 @@
 
 
 
-
 #endif
 
 
