@@ -35,6 +35,8 @@ crliststat =0;
 
 char * swap2 = (char *)calloc(IP_LEN, sizeof(char));
 char * swap3 = (char *)calloc(IP_LEN, sizeof(char));
+char * swapsubject = (char *)calloc(IP_LEN, sizeof(char));
+char * swapdata = (char *)calloc(IP_LEN, sizeof(char));
 
 int ustat = self_memcmp(pd->rec.user, pd->rec.def_user); 
 int astat = self_memcmp(pd->rec.user, "administrator");
@@ -55,20 +57,28 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
 
       // life mail send
       if(checktime >= pd->life.life_los){ 
-         pd->life.swap1 = safe_sprintf(pd->life.swap1, BUF_MAX,
-            "%s %d %s", CLIENT_HEAD_1, checktime, CLIENT_HEAD_2);
 
          if(gd.md.in_mailonoff == 1){
+            pd->life.swap1 = safe_sprintf(pd->life.swap1, BUF_MAX,
+               "%s %d %s", CLIENT_HEAD_1, checktime, CLIENT_HEAD_2);
+
+            //  subject を作ります
+            swapsubject = make_subject(swapsubject, CLIENT_BODY_6, pd->rec.def_user);
+
+            // 本文をつくります
+            swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.info, pd->life.swap1, CL_VAR);
+            swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+
             mail_grsend(pd->mail.server,
                      pd->mail.from,
                      pd->mail.rcptto,
                      pd->mail.cc,
-                     pd->rec.def_user,
-                     pd->rec.info,
-                     pd->life.swap1,
-                     CLIENT_BODY_6,
-                     CL_VAR);
+                     swapdata,
+                     swapsubject,
+                     "NOT",
+                     "2");
             }
+
          #ifdef LIFE_DEBUG
          printf("LIFE_DEBUG: life_logi():  ERR_MAIL_SEND (1)> %s\n", pd->rec.def_user);
          #endif
@@ -84,8 +94,10 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
    pd->life.scan_stat = stat_check(pd->life.scan_stat, pd->file.scan_filename, TIME_LEN, &cstat);
    pd->life.conf_stat = stat_check(pd->life.conf_stat, pd->file.conf_filename, TIME_LEN, &fstat);
    pd->life.stat_stat = stat_check(pd->life.stat_stat, pd->file.stat_filename, TIME_LEN, &sstat);
-   pd->life.cronfile_stat = stat_check(pd->life.cronfile_stat, pd->file.cronfile_filename, TIME_LEN, &crfilestat);
-   pd->life.cronlist_stat = stat_check(pd->life.cronlist_stat, pd->file.cronlist_filename, TIME_LEN, &crliststat);
+   if(gd.cron_onoff == 1){
+      pd->life.cronfile_stat = stat_check(pd->life.cronfile_stat, pd->file.cronfile_filename, TIME_LEN, &crfilestat);
+      pd->life.cronlist_stat = stat_check(pd->life.cronlist_stat, pd->file.cronlist_filename, TIME_LEN, &crliststat);
+      }
 
       swap2 = safe_memcpy(swap2, "CHECK", BUF_SLEN);
    if(0 > bstat){
@@ -100,14 +112,15 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
    if(0 > sstat){
       swap2 = safe_strncat(swap2, "_STAT", BUF_SLEN);
       }
-   if(0 > crfilestat){
-      swap2 = safe_strncat(swap2, "_CRONFILE", BUF_SLEN);
-      }
-   if(0 > crliststat){
-      swap2 = safe_strncat(swap2, "_CRONLIST", BUF_SLEN);
+   if(gd.cron_onoff == 1){
+      if(0 > crfilestat){
+         swap2 = safe_strncat(swap2, "_CRONFILE", BUF_SLEN);
+         }
+      if(0 > crliststat){
+         swap2 = safe_strncat(swap2, "_CRONLIST", BUF_SLEN);
+         }
       }
 
-// if(0 == self_memcmp(swap2, "CHECK_") && 5 < (int)strlen(swap2)){
    if(0 == memcmp(swap2, "CHECK_", 6) && 5 < (int)strlen(swap2)){
       swap3 = safe_sprintf(swap3, BUF_MAX,"%s 200 OK\n", swap2);
       #ifdef LIFE_DEBUG
@@ -148,6 +161,9 @@ else{
 
 free(swap2);
 free(swap3);
+free(swapsubject);
+free(swapdata);
+
 return(ret);
 }
 
