@@ -18,7 +18,6 @@
 extern global_data_t gd;
 
 
-
 char * mail_form(char * swap, private_data_t * pd, unsigned char * chIpadd, int * middleno)
 {
 int pri, ret;
@@ -205,7 +204,7 @@ swap_mem(swap, (char)0x01, '\n', (int)strlen(swap));
 
 /* data insert */
 pthread_mutex_lock(&pg_mutex);
-psqlexec_datain(swap);
+psqlexec_datain(pd, swap);
 pthread_mutex_unlock(&pg_mutex);
 #endif
 
@@ -286,21 +285,31 @@ else{
 
 if(pri < 3){
 
+   // 特殊用途です
+   #ifdef SERVICES_MODE
+// kanshi = safe_sprintf(kanshi, BUF_MAX,"%shttps://%s/custommer/%s/monitor_edit.php?STATUS=UPDATE&UNO=%s",
+   kanshi = safe_memcpy(kanshi, "", BUF_MAX);
+   #else
+
    // 監視設定をURLから検索させるかの判断
    #ifdef URL_SEARCH
-   kanshi = safe_sprintf(kanshi, BUF_MAX,"%shttp://%s/monitor_edit.php?STATUS=UPDATE&UNO=%s",
+// kanshi = safe_sprintf(kanshi, BUF_MAX,"%shttp://%s/monitor_edit.php?STATUS=UPDATE&UNO=%s",
+   kanshi = safe_sprintf(kanshi, BUF_MAX,"%shttp://%s/monitor_edit.php?STATUS=UPDATE&UNO=%s\n",
      MONITOR_SER, gd.pg.pg_webserver, free3);
    #else
    kanshi = safe_sprintf(kanshi, BUF_MAX,"%s%s", MONITOR_ID, free3);
    #endif
 
+   #endif
+
    /* --- mail format --- */
    if(0 == self_memcmp(tool, "INFO")){
       swap = safe_sprintf(swap, BUF_MAX, "%s\n\n",
         MAIL_DATA_1);
       }
    if(0 == self_memcmp(tool, "SNMP")){
-      swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//      swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+        swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
         MAIL_SNMP_11,
         kanshi,
         MAIL_SNMP_12,
@@ -321,7 +330,8 @@ if(pri < 3){
 
    if(0 == self_memcmp(stat, "0") && 0 == self_memcmp(tool, "PORT")){
       if(0 == self_memcmp(prot, "DHW")){
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_DHW_11,
            kanshi,
            MAIL_DHW_12,
@@ -342,7 +352,8 @@ if(pri < 3){
            info);
          }
       else if(0 == self_memcmp(prot, "URL")){
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_URL_11,
            kanshi,
            MAIL_URL_12,
@@ -363,7 +374,8 @@ if(pri < 3){
            info);
          }
       else if(0 == self_memcmp(prot, "SMTP")){
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_SMTP_11,
            kanshi,
            MAIL_SMTP_12,
@@ -384,7 +396,8 @@ if(pri < 3){
            info);
          }
       else if(0 == self_memcmp(prot, "SNTP")){
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_NTP_11,
            kanshi,
            MAIL_NTP_12,
@@ -405,7 +418,8 @@ if(pri < 3){
            info);
          }
       else{
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_PORT_11,
            kanshi,
            MAIL_PORT_12,
@@ -429,7 +443,8 @@ if(pri < 3){
 
    if(0 == self_memcmp(stat, "1") && 0 == self_memcmp(tool, "PORT")){
       if(0 == self_memcmp(prot, "DHW")){
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_DHW_21,
            kanshi,
            MAIL_DHW_22,
@@ -450,7 +465,8 @@ if(pri < 3){
            info);
          }
       else if(0 == self_memcmp(prot, "URL")){
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_URL_21,
            kanshi,
            MAIL_URL_22,
@@ -471,7 +487,8 @@ if(pri < 3){
            info);
          }
       else if(0 == self_memcmp(prot, "SMTP")){
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_SMTP_21,
            kanshi,
            MAIL_SMTP_22,
@@ -492,7 +509,8 @@ if(pri < 3){
            info);
          }
       else if(0 == self_memcmp(prot, "SNTP")){
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_NTP_21,
            kanshi,
            MAIL_NTP_22,
@@ -513,7 +531,8 @@ if(pri < 3){
            info);
          }
       else{
-         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
            MAIL_PORT_21,
            kanshi,
            MAIL_PORT_22,
@@ -536,7 +555,8 @@ if(pri < 3){
       }
 
    if(0 == self_memcmp(stat, "0") && 0 == self_memcmp(tool, "COMAND")){
-      swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//    swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+      swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
         MAIL_COMMAND_11,
         kanshi,
         MAIL_COMMAND_12,
@@ -554,7 +574,8 @@ if(pri < 3){
       }
 
    if(0 == self_memcmp(stat, "1") && 0 == self_memcmp(tool, "COMAND")){
-      swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+//    swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+      swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
         MAIL_COMMAND_21,
         kanshi,
         MAIL_COMMAND_22,
@@ -575,7 +596,6 @@ else{
    clean_mem(swap, (char)0x00, (int)strlen(swap));
    }
 
-
 mail_form_end :;
 
 free(tool);
@@ -608,4 +628,3 @@ return swap;
 
 
 
-
