@@ -14,13 +14,6 @@
 #include"jpreturn.h"
 
 
-// #ifdef POSTGRES_IN
-//  #include<libpq-fe.h>
-//  extern PGconn * conn;
-//  extern PGresult * res;
-// #endif
-
-
 extern global_data_t gd;
 
 
@@ -31,6 +24,8 @@ static int stat;
 stat = 0;
 int count = 0;
 char * tmp;
+char * swapsubject;
+char * swapdata;
 
 if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
    pd->file.lock_filename = chack_lockfile(pd->rec.user, pd->rec.info, pd->file.lock_filename, gd.fp.lock_path, &stat);
@@ -90,18 +85,20 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
       printf("DEBUG: neg_logi(): stat_filename <%s>\n", pd->file.stat_filename);
       #endif
 
-      pd->file.cronfile_filename = filename_create(pd->file.cronfile_filename, gd.fp.file_conf, ".cronfile", pd->rec.user);
 
-      #ifdef DEBUG
-      printf("DEBUG: neg_logi(): conf_filename <%s>\n", pd->file.cronfile_filename);
-      #endif
+      if(gd.cron_onoff == 1){
+         pd->file.cronfile_filename = filename_create(pd->file.cronfile_filename, gd.fp.file_conf, ".cronfile", pd->rec.user);
 
-      pd->file.cronlist_filename = filename_create(pd->file.cronlist_filename, gd.fp.file_conf, ".cronlist", pd->rec.user);
+         #ifdef DEBUG
+         printf("DEBUG: neg_logi(): conf_filename <%s>\n", pd->file.cronfile_filename);
+         #endif
 
-      #ifdef DEBUG
-      printf("DEBUG: neg_logi(): conf_filename <%s>\n", pd->file.cronlist_filename);
-      #endif
+         pd->file.cronlist_filename = filename_create(pd->file.cronlist_filename, gd.fp.file_conf, ".cronlist", pd->rec.user);
 
+         #ifdef DEBUG
+         printf("DEBUG: neg_logi(): conf_filename <%s>\n", pd->file.cronlist_filename);
+         #endif
+         }
 
 
       #ifdef LOG_OUT
@@ -150,7 +147,7 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
       #endif
 
       pthread_mutex_lock(&pg_mutex);
-      psqlexec_datain(swap);
+      psqlexec_datain(pd, swap);
       pthread_mutex_unlock(&pg_mutex);
       free(swap);
       #endif
@@ -204,17 +201,36 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
 
 
       #ifndef BIG_WOOD
+
       if(gd.md.in_mailonoff == 1){
+         swapsubject = (char *)calloc(IP_LEN, sizeof(char));
+         swapdata = (char *)calloc(IP_LEN, sizeof(char));
+
+         // subject を作ります
+         #ifdef SERVICES_MODE
+         swapsubject = safe_sprintf(swapsubject, BUF_MAX, "ZITHER Watchdog <%s> %s", pd->rec.def_user, "new connection");
+         #else
+         swapsubject = safe_sprintf(swapsubject, BUF_MAX, "ZITHER <%s> %s", pd->rec.def_user, "new connection");
+         #endif
+
+         // 本文をつくります
+         swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.info, CLIENT_BODY_5, CL_VAR);
+         swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+
          mail_grsend(pd->mail.server,
                   pd->mail.from,
                   pd->mail.rcptto,
                   pd->mail.cc,
-                  pd->rec.def_user,
-                  pd->rec.info,
-                  CLIENT_BODY_5, 
-                  "new connection",
-                  CL_VAR);
+                  swapdata, 
+                  swapsubject,
+                  "NOT",
+                  "1");
+
+
+         free(swapsubject);
+         free(swapdata);
          }
+
       #endif
 
       stat = socket_send(gd.ms.sk[pd->rec.fdno], "200 OK\n", gd.bs.life_int);
