@@ -51,7 +51,12 @@ return 0;
 
 int opt_version(void)
 {
-printf("------- %s -------\n", CL_VAR);
+#ifdef POSTGRES_IN
+printf("------- %s for postgreSQL -------\n", CL_VAR);
+#endif
+#ifdef MYSQL_IN
+printf("------- %s for mysql -------\n", CL_VAR);
+#endif
 printf("     -c /*/   config file name\n");
 printf("     -n /*/   nego file name\n");
 printf("     -i <UID> user id\n");   
