@@ -11,19 +11,11 @@
 #include<almemsys/almemsys.h>
 
 
-//extern global_data_t gd;
-
-
-// #define MYSQL_SERVER   "127.0.0.1"
-// #define MYSQL_USERNAME "masashi" 
-// #define MYSQL_PASSWORD "passswd"
-// #define MYSQL_DB       "zither" 
-
 
 int path_check(char *chA)
 {
 static int bu;
-char ch[26][IP_LEN];
+char ch[28][IP_LEN];
 int count = 0;
 char * non="NON";
 char * err_log="ERR_LOG";
@@ -50,6 +42,8 @@ char * mysql_username="MYSQL_USERNAME";
 char * mysql_password="MYSQL_PASSWORD";
 char * mysql_db="MYSQL_DB"; 
 char * db_select="DB_SELECT";
+char * on_bcc="ON_BCC";
+char * cron_onoff="CRON_ONOFF";
 
 self_memcpy(ch[0], non, IP_LEN);
 self_memcpy(ch[1], err_log, IP_LEN);
@@ -76,10 +70,12 @@ self_memcpy(ch[21], mysql_username, IP_LEN);
 self_memcpy(ch[22], mysql_password, IP_LEN);
 self_memcpy(ch[23], mysql_db, IP_LEN);
 self_memcpy(ch[24], db_select, IP_LEN);
+self_memcpy(ch[25], on_bcc, IP_LEN);
+self_memcpy(ch[26], cron_onoff, IP_LEN);
 
 bu = 0;
 if(IP_LEN > strlen(chA)){
-   for(count=0; count < 25; count++){
+   for(count=0; count < 27; count++){
       if(0 == self_memcmp(chA, ch[count])){
          bu=count;
          }
