@@ -4,7 +4,7 @@
 
 #ifdef POSTGRES_IN
 int psqlconnect(void);
-int psqlexec_datain(char *);
+int psqlexec_datain(private_data_t *, char *);
 int psqlexec_select(char *);
 int psql_connectset(private_data_t *, char *);
 #endif
@@ -18,9 +18,6 @@ int mysqlexec_select(char *);
 #endif
 
 
-// int socket_bind(struct sockaddr_in *, int, char *, int *);
-// int socket_accept(struct sockaddr_in *, int *, int *); 
-
 int malloc_set(void);
 int malloc_set2(void);
 int private_malloc_set(private_data_t *);
@@ -54,21 +51,18 @@ char * filename_create(char *, char *, char *, char *);
 
 int mail_time_getr(char [], int, char *);
 
-int mail_grsend( char *, char *, char *, char *, char *, char *, char *, char *, char *);
+int mail_grsend(char *, char *, char *, char *, char *, char *, char *, char *);
 int mail_grsend_t(mail_data_t *);
 
+char * make_subject(char *, char *, char *);
+
 int mail_malloc(mail_data_t *);
 int mail_free(mail_data_t *);
 int outchar(int *, char **, char);
-// int base64(char *, int, char *);
-// int ujtoj(unsigned char *, unsigned char *);
 int msocket_send(char *, int);
 int msocket_connect(struct sockaddr_in *, int, char [], int *);
 int send_rcpttodata(mail_data_t *, char *);
 int send_rcptto(mail_data_t *, int);
-// char * swap_rn(char *, char);
-
-
 
 int life_check(private_data_t *);
 
