@@ -1,3 +1,4 @@
+
 #include<stdio.h>
 #include<stdlib.h>
 #include<sys/types.h>
@@ -27,20 +28,29 @@ int ustat = self_memcmp(pd->rec.user, pd->rec.def_user);
 int astat = self_memcmp(pd->rec.user, "administrator");
 int cgstat = self_memcmp(pd->rec.user, "cgiuser");
 
+char * swapsubject = (char *)calloc(IP_LEN, sizeof(char));
+char * swapdata = (char *)calloc(IP_LEN, sizeof(char));
+
 ret = 0; 
 
 if(ustat == 0 || astat == 0 || cgstat == 0){ 
 
    if(gd.md.in_mailonoff == 1){
+      // subject を作ります
+      swapsubject = make_subject(swapsubject, CLIENT_BODY_8, pd->rec.def_user);
+
+      // 本文をつくります
+      swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.info, CLIENT_BODY_7, CL_VAR);
+      swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+
       mail_grsend(pd->mail.server,
                pd->mail.from,
                pd->mail.rcptto,
                pd->mail.cc,
-               pd->rec.def_user,
-               pd->rec.info,
-               CLIENT_BODY_7,
-               CLIENT_BODY_8,
-               CL_VAR);
+               swapdata,
+               swapsubject,
+               "NOT",
+               "1");
       }
 
    #ifdef LOG_OUT
@@ -58,6 +68,9 @@ else{
    ret = -1;
    } 
 
+free(swapsubject);
+free(swapdata);
+
 return(ret);
 }
 
